@@ -17,10 +17,9 @@ PREGO_TMP = os.path.join(PREGO_TMP_BASE, str(os.getpid()))
 INDENTST = 9 * ' '
 IDENTIFIERS = string.ascii_uppercase + string.ascii_lowercase
 
-PREGO_SPECS = os.path.abspath(
-    resolve_path('config.spec', ['.', '/usr/lib/prego'])[0])
-PREGO_CMD_DEFAULTS = os.path.abspath(
-    resolve_path('defaults.config', ['.', '/usr/lib/prego'])[0])
+config_path = ['.', '/usr/share/lib/prego', '/share/lib/prego']
+PREGO_SPECS = os.path.abspath(resolve_path('config.spec', config_path)[0])
+PREGO_CMD_DEFAULTS = os.path.abspath(resolve_path('defaults.config', config_path)[0])
 USER_CONFIG = os.path.abspath(os.path.join(os.environ['HOME'], '.prego'))
 CWD_CONFIG = os.path.join(os.getcwd(), '.prego')
 
